# flake8: noqa
from distutils.core import setup

long_description = """\
Jacapo is a python package providing an interface to Dacapo that
is compatible with the open source Atomic Simulation
Environment in the python scripting language."""

packages = ['Jacapo']

tools = ['tools/ncsum',
         'tools/plotnetcdf',
         'tools/pysub',
         'tools/qn_relax',
         'tools/stripnetcdf']

# Get the current version number:
exec(compile(open('version.py').read(), 'version.py', 'exec'))

setup(name = 'python-Jacapo',
      # version=version,
      description='Jacapo - ase + Dacapo',
      url='http://www.fysik.dtu.dk/Campos/ase',
      maintainer='John Kitchin',
      maintainer_email='jkitchin@andrew.cmu.edu',
      license='LGPL',
      platforms=['linux'],
      packages=packages,
      scripts=tools,
      long_description=long_description)
